==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DepozytPSwWplata.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class DepozytPSwWplata extends GenericDPSObject {
    /**
     * DEPOZYT_P_SW_WPLATA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * DEPOZYT_P_SW_WPLATA.TERMIN_WYPLATY_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long terminWyplatyId;

    /**
     * DEPOZYT_P_SW_WPLATA.DATA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date data;

    /**
     * DEPOZYT_P_SW_WPLATA.DATA_KSIEGOWANIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataKsiegowania;

    /**
     * DEPOZYT_P_SW_WPLATA.MIESIAC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer miesiac;

    /**
     * DEPOZYT_P_SW_WPLATA.ROK
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer rok;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DEPOZYT_P_SW_WPLATA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DEPOZYT_P_SW_WPLATA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DEPOZYT_P_SW_WPLATA.TERMIN_WYPLATY_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getTerminWyplatyId() {
        return terminWyplatyId;
    }

    /**
     * DEPOZYT_P_SW_WPLATA.TERMIN_WYPLATY_ID
     *
     * @param terminWyplatyId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTerminWyplatyId(Long terminWyplatyId) {
        this.terminWyplatyId = terminWyplatyId;
    }

    /**
     * @return DEPOZYT_P_SW_WPLATA.DATA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getData() {
        return data;
    }

    /**
     * DEPOZYT_P_SW_WPLATA.DATA
     *
     * @param data
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return DEPOZYT_P_SW_WPLATA.DATA_KSIEGOWANIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataKsiegowania() {
        return dataKsiegowania;
    }

    /**
     * DEPOZYT_P_SW_WPLATA.DATA_KSIEGOWANIA
     *
     * @param dataKsiegowania
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataKsiegowania(Date dataKsiegowania) {
        this.dataKsiegowania = dataKsiegowania;
    }

    /**
     * @return DEPOZYT_P_SW_WPLATA.MIESIAC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getMiesiac() {
        return miesiac;
    }

    /**
     * DEPOZYT_P_SW_WPLATA.MIESIAC
     *
     * @param miesiac
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setMiesiac(Integer miesiac) {
        this.miesiac = miesiac;
    }

    /**
     * @return DEPOZYT_P_SW_WPLATA.ROK
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getRok() {
        return rok;
    }

    /**
     * DEPOZYT_P_SW_WPLATA.ROK
     *
     * @param rok
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRok(Integer rok) {
        this.rok = rok;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DepozytPSwWplata other = (DepozytPSwWplata) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getTerminWyplatyId() == null ? other.getTerminWyplatyId() == null : this.getTerminWyplatyId().equals(other.getTerminWyplatyId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getDataKsiegowania() == null ? other.getDataKsiegowania() == null : this.getDataKsiegowania().equals(other.getDataKsiegowania()))
            && (this.getMiesiac() == null ? other.getMiesiac() == null : this.getMiesiac().equals(other.getMiesiac()))
            && (this.getRok() == null ? other.getRok() == null : this.getRok().equals(other.getRok()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getTerminWyplatyId() == null) ? 0 : getTerminWyplatyId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getDataKsiegowania() == null) ? 0 : getDataKsiegowania().hashCode());
        result = prime * result + ((getMiesiac() == null) ? 0 : getMiesiac().hashCode());
        result = prime * result + ((getRok() == null) ? 0 : getRok().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", terminWyplatyId=").append(terminWyplatyId);
        sb.append(", data=").append(data);
        sb.append(", dataKsiegowania=").append(dataKsiegowania);
        sb.append(", miesiac=").append(miesiac);
        sb.append(", rok=").append(rok);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DepozytPSwWplata.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class DepozytPSwWplata extends GenericDPSObject {
    /**
     * DEPOZYT_P_SW_WPLATA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * DEPOZYT_P_SW_WPLATA.TERMIN_WYPLATY_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long terminWyplatyId;

    /**
     * DEPOZYT_P_SW_WPLATA.DATA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date data;

    /**
     * DEPOZYT_P_SW_WPLATA.DATA_KSIEGOWANIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataKsiegowania;

    /**
     * DEPOZYT_P_SW_WPLATA.MIESIAC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer miesiac;

    /**
     * DEPOZYT_P_SW_WPLATA.ROK
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer rok;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DEPOZYT_P_SW_WPLATA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DEPOZYT_P_SW_WPLATA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DEPOZYT_P_SW_WPLATA.TERMIN_WYPLATY_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getTerminWyplatyId() {
        return terminWyplatyId;
    }

    /**
     * DEPOZYT_P_SW_WPLATA.TERMIN_WYPLATY_ID
     *
     * @param terminWyplatyId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTerminWyplatyId(Long terminWyplatyId) {
        this.terminWyplatyId = terminWyplatyId;
    }

    /**
     * @return DEPOZYT_P_SW_WPLATA.DATA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getData() {
        return data;
    }

    /**
     * DEPOZYT_P_SW_WPLATA.DATA
     *
     * @param data
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return DEPOZYT_P_SW_WPLATA.DATA_KSIEGOWANIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataKsiegowania() {
        return dataKsiegowania;
    }

    /**
     * DEPOZYT_P_SW_WPLATA.DATA_KSIEGOWANIA
     *
     * @param dataKsiegowania
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataKsiegowania(Date dataKsiegowania) {
        this.dataKsiegowania = dataKsiegowania;
    }

    /**
     * @return DEPOZYT_P_SW_WPLATA.MIESIAC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getMiesiac() {
        return miesiac;
    }

    /**
     * DEPOZYT_P_SW_WPLATA.MIESIAC
     *
     * @param miesiac
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setMiesiac(Integer miesiac) {
        this.miesiac = miesiac;
    }

    /**
     * @return DEPOZYT_P_SW_WPLATA.ROK
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getRok() {
        return rok;
    }

    /**
     * DEPOZYT_P_SW_WPLATA.ROK
     *
     * @param rok
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRok(Integer rok) {
        this.rok = rok;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DepozytPSwWplata other = (DepozytPSwWplata) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getTerminWyplatyId() == null ? other.getTerminWyplatyId() == null : this.getTerminWyplatyId().equals(other.getTerminWyplatyId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getDataKsiegowania() == null ? other.getDataKsiegowania() == null : this.getDataKsiegowania().equals(other.getDataKsiegowania()))
            && (this.getMiesiac() == null ? other.getMiesiac() == null : this.getMiesiac().equals(other.getMiesiac()))
            && (this.getRok() == null ? other.getRok() == null : this.getRok().equals(other.getRok()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getTerminWyplatyId() == null) ? 0 : getTerminWyplatyId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getDataKsiegowania() == null) ? 0 : getDataKsiegowania().hashCode());
        result = prime * result + ((getMiesiac() == null) ? 0 : getMiesiac().hashCode());
        result = prime * result + ((getRok() == null) ? 0 : getRok().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", terminWyplatyId=").append(terminWyplatyId);
        sb.append(", data=").append(data);
        sb.append(", dataKsiegowania=").append(dataKsiegowania);
        sb.append(", miesiac=").append(miesiac);
        sb.append(", rok=").append(rok);
        sb.append("]");
        return sb.toString();
    }
}
